# panamap

[![Build Status](https://travis-ci.com/kirillsulim/panamap.svg?branch=master)](https://travis-ci.com/kirillsulim/panamap)
[![PyPI version](https://badge.fury.io/py/panamap.svg)](https://badge.fury.io/py/panamap)
![Coveralls github](https://img.shields.io/coveralls/github/kirillsulim/panamap)


Panamap is python object mapper.
